module Rack

  module ConsoleAuth
    class BasicAuth

      def initialize(app)
        @app = app
      end

      def call(env)
        auth = Rack::Auth::Basic::Request.new(env)
        request = Rack::Request.new(env)

        unless (auth.provided? and auth.basic? and auth.credentials)
          return @app.call(env)
        end

        ::ConsoleAuth.logger.info "Authentication method is Basic Auth. Skipping session management"

        username, password = auth.credentials
        env['rack.session']['rack.basic.user'] = username

        user = ::ConsoleAuth.get_user(env)

        if user.nil?
          ::ConsoleAuth.logger.error "Unauthorized request to #{request.path} from IP address #{request.ip}. User (#{username}) not found"
          return [401, {}, '<h1>Unauthorized</h1>']
        end

        if user and user.status == 'enabled' and valid_password? :user => user, :password => password
          ::ConsoleAuth.logger.info "Successful authentiation by user #{username} from IP address #{Rack::Request.new(env).ip}"
          return @app.call env
        else
          ::ConsoleAuth.logger.error "Failed authentiation by user #{username} from IP address #{Rack::Request.new(env).ip}"
          return [401, {}, '<h1>Unauthorized</h1>']
        end
      end

      def valid_password?(params)
        user = params[:user]
        pass = params[:password]

        user.encrypted_password == Digest::SHA256.hexdigest("#{user.encryption_salt}::#{pass}")
      end

    end
  end
end
