class ConsoleAuth::Restriction
  require "#{File.dirname(__FILE__)}/restriction/method"

  attr_accessor :name, :methods

  def initialize(name, &blk)
    @name    = name
    @methods = Array.new

    unless [Regexp, String].include? name.class
      raise 'A restriction must be a regular expression or a string'
    end

    self.instance_exec &blk
  end

  def [](index)
    @methods.find do |method|
      method.name == index
    end
  end

  def has_unauthenticated_method?
    found_method = @methods.find do |method|
      method.allow_unauthenticated?
    end

    #If we didn't find anything (nil), we don't
    #have any unauthenticatable methods
    found_method.nil? ? false : true
  end

  def method(*names, &blk)
    names.each do |meth|
      @methods << ConsoleAuth::Restriction::Method.new(meth, &blk)
    end
  end

  def match?(url)
    if @name.is_a? Regexp
      url =~ @name
    else
      url == @name
    end
  end
end
